@@ -1,14 +1,6 @@
-#ifndef __GNOME_PRINT_MASTER_PRIVATE_H__
-#define __GNOME_PRINT_MASTER_PRIVATE_H__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000 Ximian Inc.
- *
- *  Authors:
- *    Michael Zucchi <notzed@ximian.com>
- *    Lauris Kaplinski <lauris@ximian.com>
- *
- *  A system print interface.
+ *  gnome-print-job-private.h:
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -23,21 +15,30 @@
  *  You should have received a copy of the GNU Library General Public
  *  License along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Michael Zucchi <notzed@ximian.com>
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *
+ *  Copyright 2000-2003 Ximian, Inc.
  */
 
+#ifndef __GNOME_PRINT_JOB_PRIVATE_H__
+#define __GNOME_PRINT_JOB_PRIVATE_H__
+
 #include <glib.h>
 
 G_BEGIN_DECLS
 
-#include "gnome-print-job.h"
+#include <libgnomeprint/gnome-print-job.h>
+
+typedef struct _GnomePrintJobClass GnomePrintJobClass;
 
 struct _GnomePrintJob {
 	GObject object;
-
+	
 	GnomePrintConfig *config;
-
 	GnomePrintContext *meta;
-
 	gpointer priv;
 };
 
@@ -47,5 +48,4 @@ struct _GnomePrintJobClass {
 
 G_END_DECLS
 
-#endif
-
+#endif /* __GNOME_PRINT_JOB_PRIVATE_H__ */
