@@ -65,6 +65,10 @@ xmlChar *model_xml_template =
 "          <Key Id=\"Bottom\" Value=\"0\"/>"
 "        </Key>"
 "      </Option>"
+"      <Option Id=\"Job\">"
+"        <Option Id=\"NumCopies\" Type=\"String\" Default=\"1\"/>"
+"        <Option Id=\"Collate\" Type=\"String\" Default=\"false\"/>"
+"      </Option>"
 "    </Option>"
 "    <Option Id=\"Document\">"
 "      <Option Id=\"Page\">"
